==> cebra-0.1.0rc3-py2.py3-none-any.whl: cebra-0.1.0rc3.dist-info/LICENSE.md <==
**Non-Commercial License Agreement: CEBRA**

© All rights reserved. ECOLE POLYTECHNIQUE FÉDÉRALE DE LAUSANNE, Switzerland,
Laboratory of Prof. Mackenzie W. Mathis (UPMWMATHIS) and original authors:
Steffen Schneider, Jin H Lee, Mackenzie W Mathis. 2023.

**Introduction**

- This license agreement sets forth the terms and conditions under which ECOLE POLYTECHNIQUE FEDERALE DE LAUSANNE ( EPFL),
CH-1015 Lausanne, Switzerland and Prof. Mackenzie W. Mathis and code authors (hereafter "LICENSOR") will grant you 
(hereafter "LICENSEE") a fully-paid, non-exclusive, and non-transferable license for academic, non-commercial purposes only
(hereafter “LICENSE”) to use the "CEBRA" computer software program (hereafter "PROGRAM").

- LICENSEE acknowledges that the PROGRAM is a research tool that is being supplied "as is", without any related services,
improvements or warranties from LICENSOR and that this license is entered into in order to enable others to utilize the
PROGRAM in their academic activities. 

- The ideas covered in this work is also patent pending (as of Jan 2023): US 63/302,670 “DIMENSIONALITY REDUCTION OF TIME-SERIES DATA, 
AND SYSTEMS AND DEVICES THAT USE THE RESULTANT EMBEDDINGS”

- If this license is not appropriate for your application, please contact Prof. Mackenzie W. Mathis (mackenzie@post.harvard.edu)
and/or the TTO office at EPFL (tto@epfl.ch) for a commercial use license.

**Terms and Conditions of the LICENSE**
1.	LICENSOR grants to LICENSEE a fully-paid up, non-exclusive, and non-transferable license to use the PROGRAM for academic,
    non-commercial purposes, upon the terms and conditions hereinafter set out and until termination of this license as set 
    forth below.

2.	LICENSEE acknowledges the PROGRAM is provided "as is", without any related services or improvements from LICENSOR and 
    that the LICENSE is entered into in order to enable others to utilize the PROGRAM in their academic activities.

3.	LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY REPRESENTATIONS OR
    WARRANTIES OF MERCHANTABILITY OR FITNESS FOR PARTICULAR PURPOSE OR THAT THE USE OF THE PROGRAM WILL NOT INFRINGE ANY 
    PATENTS, COPYRIGHTS, TRADEMARKS OR OTHER RIGHTS. LICENSOR shall not be liable for any direct, indirect or consequential
    damages with respect to any claim by LICENSEE or any third party arising from this Agreement or use of the PROGRAM.
    
4.	LICENSEE agrees that it will use the PROGRAM, and any modifications, improvements, or derivatives to PROGRAM that 
    LICENSEE may create (collectively, "IMPROVEMENTS") solely for academic, non-commercial purposes and shall not 
    distribute or transfer the PROGRAM or any IMPROVEMENTS to any person without prior written permission from LICENSOR.
    Any IMPROVEMENTS must remain open source with a copy of this license. The terms "academic, non-commercial", as used
    in this Agreement, mean academic or other scholarly research which (a) is not undertaken for profit, or (b) is not 
    intended to produce works, services, or data for commercial use, or (c) is neither conducted, nor funded, by a person
    or an entity engaged in the commercial use, application or exploitation of works similar to the PROGRAM.

5.	LICENSEE agrees that they shall credit the use of CEBRA with an appropriate citation: 
    Steffen Schneider, Jin H. Lee, Mackenzie Weygandt Mathis. Learnable latent embeddings for joint behavioral 
    and neural analysis. Nature 2023 doi: _pending_.

6.	Ownership of all rights, including copyright in the PROGRAM and in any material associated therewith, shall at all times
   remain with LICENSOR and LICENSEE agrees to preserve the same. LICENSEE agrees not to use any portion of the PROGRAM or 
   of any IMPROVEMENTS in any machine-readable form outside the PROGRAM, nor to make any copies except for its internal use, 
   without prior written consent of LICENSOR. LICENSEE agrees to maintain this license file with the source code and place the
   following copyright notice on any such copies: 

      © All rights reserved. ECOLE POLYTECHNIQUE FÉDÉRALE DE LAUSANNE, Switzerland, Laboratory of Prof. Mackenzie W. Mathis
      (UPMWMATHIS) and original authors: Steffen Schneider, Jin H Lee, Mackenzie W Mathis. 2023.

7.	The LICENSE shall not be construed to confer any rights upon LICENSEE by implication or otherwise except as specifically
    set forth herein.

8.	This Agreement shall be governed by the material laws of Switzerland and any dispute arising out of this Agreement or 
    use of the PROGRAM shall be brought before the courts of Lausanne, Switzerland. 

9.	This Agreement and the LICENSE shall remain effective until expiration of the copyrights of the PROGRAM except that, 
    upon any breach of this Agreement by LICENSEE, LICENSOR shall have the right to terminate the LICENSE immediately upon
    notice to LICENSEE.

==> cebra-0.2.0-py2.py3-none-any.whl: cebra-0.2.0.dist-info/LICENSE.md <==
**Non-Commercial License Agreement: CEBRA**

© All rights reserved. ECOLE POLYTECHNIQUE FÉDÉRALE DE LAUSANNE, Switzerland,
Laboratory of Prof. Mackenzie W. Mathis (UPMWMATHIS) and original authors:
Steffen Schneider, Jin H Lee, Mackenzie W Mathis. 2023.

**Introduction**

- This license agreement sets forth the terms and conditions under which ECOLE POLYTECHNIQUE FEDERALE DE LAUSANNE ( EPFL),
CH-1015 Lausanne, Switzerland and Prof. Mackenzie W. Mathis and code authors (hereafter "LICENSOR") will grant you 
(hereafter "LICENSEE") a fully-paid, non-exclusive, and non-transferable license for academic, non-commercial purposes only
(hereafter “LICENSE”) to use the "CEBRA" computer software program (hereafter "PROGRAM").

- LICENSEE acknowledges that the PROGRAM is a research tool that is being supplied "as is", without any related services,
improvements or warranties from LICENSOR and that this license is entered into in order to enable others to utilize the
PROGRAM in their academic activities. 

- The ideas covered in this work is also patent pending (as of Jan 2023): US 63/302,670 “DIMENSIONALITY REDUCTION OF TIME-SERIES DATA, 
AND SYSTEMS AND DEVICES THAT USE THE RESULTANT EMBEDDINGS”

- If this license is not appropriate for your application, please contact Prof. Mackenzie W. Mathis (mackenzie@post.harvard.edu)
and/or the TTO office at EPFL (tto@epfl.ch) for a commercial use license.

**Terms and Conditions of the LICENSE**
1.	LICENSOR grants to LICENSEE a fully-paid up, non-exclusive, and non-transferable license to use the PROGRAM for academic,
    non-commercial purposes, upon the terms and conditions hereinafter set out and until termination of this license as set 
    forth below.

2.	LICENSEE acknowledges the PROGRAM is provided "as is", without any related services or improvements from LICENSOR and 
    that the LICENSE is entered into in order to enable others to utilize the PROGRAM in their academic activities.

3.	LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY REPRESENTATIONS OR
    WARRANTIES OF MERCHANTABILITY OR FITNESS FOR PARTICULAR PURPOSE OR THAT THE USE OF THE PROGRAM WILL NOT INFRINGE ANY 
    PATENTS, COPYRIGHTS, TRADEMARKS OR OTHER RIGHTS. LICENSOR shall not be liable for any direct, indirect or consequential
    damages with respect to any claim by LICENSEE or any third party arising from this Agreement or use of the PROGRAM.
    
4.	LICENSEE agrees that it will use the PROGRAM, and any modifications, improvements, or derivatives to PROGRAM that 
    LICENSEE may create (collectively, "IMPROVEMENTS") solely for academic, non-commercial purposes and shall not 
    distribute or transfer the PROGRAM or any IMPROVEMENTS to any person without prior written permission from LICENSOR.
    Any IMPROVEMENTS must remain open source with a copy of this license. The terms "academic, non-commercial", as used
    in this Agreement, mean academic or other scholarly research which (a) is not undertaken for profit, or (b) is not 
    intended to produce works, services, or data for commercial use, or (c) is neither conducted, nor funded, by a person
    or an entity engaged in the commercial use, application or exploitation of works similar to the PROGRAM.

5.	LICENSEE agrees that they shall credit the use of CEBRA with an appropriate citation: 
    Steffen Schneider, Jin H. Lee, Mackenzie Weygandt Mathis. Learnable latent embeddings for joint behavioral 
    and neural analysis. Nature 2023 doi: https://doi.org/10.1038/s41586-023-06031-6.

6.	Ownership of all rights, including copyright in the PROGRAM and in any material associated therewith, shall at all times
   remain with LICENSOR and LICENSEE agrees to preserve the same. LICENSEE agrees not to use any portion of the PROGRAM or 
   of any IMPROVEMENTS in any machine-readable form outside the PROGRAM, nor to make any copies except for its internal use, 
   without prior written consent of LICENSOR. LICENSEE agrees to maintain this license file with the source code and place the
   following copyright notice on any such copies: 

      © All rights reserved. ECOLE POLYTECHNIQUE FÉDÉRALE DE LAUSANNE, Switzerland, Laboratory of Prof. Mackenzie W. Mathis
      (UPMWMATHIS) and original authors: Steffen Schneider, Jin H Lee, Mackenzie W Mathis. 2023.

7.	The LICENSE shall not be construed to confer any rights upon LICENSEE by implication or otherwise except as specifically
    set forth herein.

8.	This Agreement shall be governed by the material laws of Switzerland and any dispute arising out of this Agreement or 
    use of the PROGRAM shall be brought before the courts of Lausanne, Switzerland. 

9.	This Agreement and the LICENSE shall remain effective until expiration of the copyrights of the PROGRAM except that, 
    upon any breach of this Agreement by LICENSEE, LICENSOR shall have the right to terminate the LICENSE immediately upon
    notice to LICENSEE.
